@@ -42,49 +42,70 @@ int main(int argc, char *argv[])
     /* Add error exit handler */
     atexit(&error_exit);
 
-    /* Parse configuration file */
-    config_file_parse(argc, argv);
-    atexit(&config_exit);
-
-    /* Parse command-line options */
+    /* Parse command-line options (1st pass) */
     options_parse(argc, argv);
 
-    /* List available serial devices */
-    if (option.list_devices)
-    {
-        list_serial_devices();
-        return status;
-    }
+    /* Parse configuration file */
+    config_file_parse();
+
+    /* Parse command-line options (2nd pass) */
+    options_parse_final(argc, argv);
 
     /* Configure tty device */
     tty_configure();
 
     /* Configure input terminal */
-    stdin_configure();
+    if (isatty(fileno(stdin)))
+    {
+       stdin_configure();
+    }
+    else
+    {
+        // Enter non interactive mode
+        interactive_mode = false;
+    }
 
     /* Configure output terminal */
-    stdout_configure();
+    if (isatty(fileno(stdout)))
+    {
+        stdout_configure();
+    }
+    else
+    {
+        // No color when piping
+        option.color = -1;
+    }
 
     /* Add log exit handler */
     atexit(&log_exit);
 
     /* Create log file */
     if (option.log)
+    {
         log_open(option.log_filename);
+    }
 
-    /* Enable ANSI text formatting (colors etc.) */
-    print_enable_ansi_formatting();
+    /* Initialize ANSI text formatting (colors etc.) */
+    print_init_ansi_formatting();
 
     /* Print launch hints */
     tio_printf("tio v%s", VERSION);
-    tio_printf("Press ctrl-t q to quit");
+    if (interactive_mode)
+    {
+        tio_printf("Press ctrl-t q to quit");
+    }
 
     /* Open socket */
-    socket_configure();
+    if (option.socket)
+    {
+        socket_configure();
+    }
 
     /* Connect to tty device */
-    if (option.no_autoconnect)
+    if ((option.no_autoconnect) || (!interactive_mode))
+    {
         status = tty_connect();
+    }
     else
     {
         /* Enter connect loop */
