@@ -42,6 +42,7 @@ enum opt_t
     OPT_TIMESTAMP_FORMAT,
     OPT_LOG_FILE,
     OPT_LOG_STRIP,
+    OPT_DTR_PULSE_DURATION,
 };
 
 /* Default options */
@@ -54,6 +55,7 @@ struct option_t option =
     .stopbits = 1,
     .parity = "none",
     .output_delay = 0,
+    .dtr_pulse_duration = 100,
     .no_autoconnect = false,
     .log = false,
     .log_filename = NULL,
@@ -70,7 +72,7 @@ void print_help(char *argv[])
 {
     printf("Usage: %s [<options>] <tty-device|sub-config>\n", argv[0]);
     printf("\n");
-    printf("Connect to tty-device directly or via sub-configuration.\n");
+    printf("Connect to tty device directly or via sub-configuration.\n");
     printf("\n");
     printf("Options:\n");
     printf("  -b, --baudrate <bps>             Baud rate (default: 115200)\n");
@@ -79,6 +81,7 @@ void print_help(char *argv[])
     printf("  -s, --stopbits 1|2               Stop bits (default: 1)\n");
     printf("  -p, --parity odd|even|none       Parity (default: none)\n");
     printf("  -o, --output-delay <ms>          Output delay (default: 0)\n");
+    printf("      --dtr-pulse-duration <ms>    DTR pulse duration (default: 100)\n");
     printf("  -n, --no-autoconnect             Disable automatic connect\n");
     printf("  -e, --local-echo                 Enable local echo\n");
     printf("  -t, --timestamp                  Enable line timestamp\n");
@@ -89,7 +92,7 @@ void print_help(char *argv[])
     printf("      --log-strip                  Strip control characters and escape sequences\n");
     printf("  -m, --map <flags>                Map special characters\n");
     printf("  -c, --color 0..255|none|list     Colorize tio text (default: 15)\n");
-    printf("  -S, --socket <socket>            Redirect I/O to socket\n");
+    printf("  -S, --socket <socket>            Redirect I/O to file or network socket\n");
     printf("  -x, --hexadecimal                Enable hexadecimal mode\n");
     printf("  -v, --version                    Display version\n");
     printf("  -h, --help                       Display help\n");
@@ -101,12 +104,12 @@ void print_help(char *argv[])
     printf("See the man page for more details.\n");
 }
 
-const char* timestamp_token(enum timestamp_t timestamp)
+const char* timestamp_state_to_string(enum timestamp_t timestamp)
 {
     switch (timestamp)
     {
         case TIMESTAMP_NONE:
-            return "none";
+            return "disabled";
             break;
 
         case TIMESTAMP_24HOUR:
@@ -117,6 +120,10 @@ const char* timestamp_token(enum timestamp_t timestamp)
             return "24hour-start";
             break;
 
+        case TIMESTAMP_24HOUR_DELTA:
+            return "24hour-delta";
+            break;
+
         case TIMESTAMP_ISO8601:
             return "iso8601";
             break;
@@ -133,18 +140,22 @@ enum timestamp_t timestamp_option_parse(const char *arg)
     
     if (arg != NULL)
     {
-        if (strcmp(arg, "24hour-start") == 0)
+        if (strcmp(arg, "24hour") == 0)
+        {
+            return TIMESTAMP_24HOUR;
+        }
+        else if (strcmp(arg, "24hour-start") == 0)
         {
             return TIMESTAMP_24HOUR_START;
         }
+        else if (strcmp(arg, "24hour-delta") == 0)
+        {
+            return TIMESTAMP_24HOUR_DELTA;
+        }
         else if (strcmp(arg, "iso8601") == 0)
         {
             return TIMESTAMP_ISO8601;
         }
-        else
-        {
-            warning_printf("Unknown timestamp type, falling back to '24hour' default format");
-        }
     }
 
     return timestamp;
@@ -159,8 +170,9 @@ void options_print()
     tio_printf(" Stopbits: %d", option.stopbits);
     tio_printf(" Parity: %s", option.parity);
     tio_printf(" Local echo: %s", option.local_echo ? "enabled" : "disabled");
-    tio_printf(" Timestamps: %s", timestamp_token(option.timestamp));
+    tio_printf(" Timestamp: %s", timestamp_state_to_string(option.timestamp));
     tio_printf(" Output delay: %d", option.output_delay);
+    tio_printf(" DTR pulse duration: %d", option.dtr_pulse_duration);
     tio_printf(" Auto connect: %s", option.no_autoconnect ? "disabled" : "enabled");
     if (option.map[0] != 0)
         tio_printf(" Map flags: %s", option.map);
@@ -190,6 +202,7 @@ void options_parse(int argc, char *argv[])
             {"stopbits",         required_argument, 0, 's'                  },
             {"parity",           required_argument, 0, 'p'                  },
             {"output-delay",     required_argument, 0, 'o'                  },
+            {"dtr-pulse-duration",   required_argument, 0, OPT_DTR_PULSE_DURATION   },
             {"no-autoconnect",   no_argument,       0, 'n'                  },
             {"local-echo",       no_argument,       0, 'e'                  },
             {"timestamp",        no_argument,       0, 't'                  },
@@ -253,6 +266,10 @@ void options_parse(int argc, char *argv[])
                 option.output_delay = string_to_long(optarg);
                 break;
 
+            case OPT_DTR_PULSE_DURATION:
+                option.dtr_pulse_duration = string_to_long(optarg);
+                break;
+
             case 'n':
                 option.no_autoconnect = true;
                 break;
@@ -357,7 +374,7 @@ void options_parse(int argc, char *argv[])
 
     if (strlen(option.tty_device) == 0)
     {
-        printf("Error: Missing device or config name\n");
+        printf("Error: Missing tty device or sub-configuration name\n");
         exit(EXIT_FAILURE);
     }
 
