@@ -31,11 +31,11 @@ enum timestamp_t
     TIMESTAMP_NONE,
     TIMESTAMP_24HOUR,
     TIMESTAMP_24HOUR_START,
+    TIMESTAMP_24HOUR_DELTA,
     TIMESTAMP_ISO8601,
     TIMESTAMP_END,
 };
 
-const char* timestamp_token(enum timestamp_t timestamp);
 enum timestamp_t timestamp_option_parse(const char *arg);
 
 /* Options */
@@ -48,6 +48,7 @@ struct option_t
     int stopbits;
     char *parity;
     int output_delay;
+    int dtr_pulse_duration;
     bool no_autoconnect;
     bool log;
     bool log_strip;
