@@ -1,7 +1,7 @@
 /*
- * tio - a simple TTY terminal I/O application
+ * tio - a simple serial terminal I/O tool
  *
- * Copyright (c) 2017  Martin Lund
+ * Copyright (c) 2017-2022  Martin Lund
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,9 +19,11 @@
  * 02110-1301, USA.
  */
 
+#define termios asmtermios
 #include <sys/ioctl.h>
-#include <asm/ioctls.h>
-#include <asm/termbits.h>
+#undef termios
+#include <asm-generic/ioctls.h>
+#include <asm-generic/termbits.h>
 
 int setspeed2(int fd, int baudrate)
 {
