@@ -256,6 +256,7 @@ void handle_command_sequence(char input_char, char previous_char, char *output_c
                 tio_printf(" ctrl-t b   Send break");
                 tio_printf(" ctrl-t c   Show configuration");
                 tio_printf(" ctrl-t d   Toggle DTR line");
+                tio_printf(" ctrl-t D   Pulse DTR line");
                 tio_printf(" ctrl-t e   Toggle local echo mode");
                 tio_printf(" ctrl-t h   Toggle hexadecimal mode");
                 tio_printf(" ctrl-t l   Clear screen");
@@ -286,6 +287,12 @@ void handle_command_sequence(char input_char, char previous_char, char *output_c
                 toggle_line("DTR", TIOCM_DTR);
                 break;
 
+            case KEY_SHIFT_D:
+                toggle_line("DTR", TIOCM_DTR);
+                delay(option.dtr_pulse_duration);
+                toggle_line("DTR", TIOCM_DTR);
+                break;
+
             case KEY_R:
                 toggle_line("RTS", TIOCM_RTS);
                 break;
@@ -355,6 +362,9 @@ void handle_command_sequence(char input_char, char previous_char, char *output_c
                     case TIMESTAMP_24HOUR_START:
                         tio_printf("Switched to 24hour-start timestamp mode");
                         break;
+                    case TIMESTAMP_24HOUR_DELTA:
+                        tio_printf("Switched to 24hour-delta timestamp mode");
+                        break;
                     case TIMESTAMP_ISO8601:
                         tio_printf("Switched to iso8601 timestamp mode");
                         break;
